@@ -59,10 +59,11 @@ def encode_value(v):
     then enclose it in curly braces and escape all right curly braces.
     """
     print('v-> ', v)
-    # try:
-    if (not type(v) is dict) and ';' in v or v.strip(' ').startswith('{'):
+    if type(v) is dict:
+        print('worked----')
+        return v
+    if ';' in v or v.strip(' ').startswith('{'):
         return '{%s}' % (v.replace('}', '}}'),)
-    print('Skipped-------------------')
     return v
 
 
